@@ -127,14 +127,25 @@ if [[ ${PULL_ASSETS} -eq 1 ]]; then
 	TARGZs="${TARGZs} resources.tgz"
 
 	SCRIPT_BRANCH="$(git rev-parse --abbrev-ref HEAD 2>/dev/null || true)"
-    if [[ $SCRIPT_BRANCH != "devspaces-3."*"-rhel-8" ]]; then
-        SCRIPT_BRANCH="devspaces-3-rhel-8"
-    fi
-    
-    # save current branch name to the temporary file, it will be used in the openvsx-builder.Dockerfile build
-    echo "$SCRIPT_BRANCH" > current_branch
+	if [[ $SCRIPT_BRANCH != "devspaces-3."*"-rhel-8" ]]; then
+		SCRIPT_BRANCH="devspaces-3-rhel-8"
+	fi
+
+	# save current branch name to the temporary file, it will be used in the openvsx-builder.Dockerfile build
+	echo "$SCRIPT_BRANCH" > current_branch
+
+	# load job-config.json file
+	base_dir=$(cd "$(dirname "$0")"; pwd)
+	jobconfigjson="${base_dir}/job-config.json"
+	echo "Load ${jobconfigjson}"
+	# get the tag of che-openvsx from job-config.json
+	REGISTRY_VERSION=$(jq -r '.Version' "${jobconfigjson}");
+	echo "REGISTRY_VERSION ${REGISTRY_VERSION}"
+	CHE_OPENVSX_TAG=$(jq -r --arg REGISTRY_VERSION "${REGISTRY_VERSION}" '.Other["CHE_OPENVSX_TAG"][$REGISTRY_VERSION]' "${jobconfigjson}");
+	echo "CHE_OPENVSX_TAG ${CHE_OPENVSX_TAG}"
+
 	# build 2 new tarballs
-	buildTarball "/openvsx-server.tar.gz" "che-openvsx" "build/dockerfiles/openvsx-builder.Dockerfile" "--target builder"
+	buildTarball "/openvsx-server.tar.gz" "che-openvsx" "build/dockerfiles/openvsx-builder.Dockerfile" "--target builder --build-arg CHE_OPENVSX_TAG=${CHE_OPENVSX_TAG}"
 	buildTarball "opt/app-root/src/ovsx.tar.gz" "che-ovsx" "build/dockerfiles/ovsx-installer.Dockerfile" "--target builder"
 	# remove temporary file
 	rm current_branch 
@@ -164,11 +175,11 @@ if [[ ${TAR_DIFF} ]] || [[ ${PULL_ASSETS} -eq 1 ]]; then
 		log "[INFO] #1 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
 		git status || true
 		gitbranch="$(git rev-parse --abbrev-ref HEAD)"
-		if [[ $scratchFlag == "--scratch" ]]; then gitbranch="devspaces-3-rhel-8"; fi
 		target=${gitbranch}-containers-candidate
+		if [[ $scratchFlag == "--scratch" ]]; then target=devspaces-3-rhel-8-containers-candidate; fi
 		repo="$(git remote -v | grep origin | head -1 | sed -r -e "s#.+/containers/(.+) \(fetch.+#\1#")"
 		sha="$(git rev-parse HEAD)"
-		tmpfile=$(mktemp) && brew container-build ${target} git+https://pkgs.devel.redhat.com/git/containers/${repo}#${sha} --git-branch ${gitbranch} --nowait 2>/dev/null | tee 2>&1 "${tmpfile}"
+		tmpfile=$(mktemp) && brew container-build ${target} git+https://pkgs.devel.redhat.com/git/containers/${repo}#${sha} --git-branch ${gitbranch} ${scratchFlag} --nowait 2>/dev/null | tee 2>&1 "${tmpfile}"
 		taskID=$(cat "${tmpfile}" | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 "${tmpfile}"
 		ERRORS="$(grep "image build failed" "${tmpfile}")" && rm -f "${tmpfile}"
 		if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
@@ -182,11 +193,11 @@ else
 		log "[INFO] #2 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
 		git status || true
 		gitbranch="$(git rev-parse --abbrev-ref HEAD)"
-		if [[ $scratchFlag == "--scratch" ]]; then gitbranch="devspaces-3-rhel-8"; fi
 		target=${gitbranch}-containers-candidate
+		if [[ $scratchFlag == "--scratch" ]]; then target=devspaces-3-rhel-8-containers-candidate; fi
 		repo="$(git remote -v | grep origin | head -1 | sed -r -e "s#.+/containers/(.+) \(fetch.+#\1#")"
 		sha="$(git rev-parse HEAD)"
-		tmpfile=$(mktemp) && brew container-build ${target} git+https://pkgs.devel.redhat.com/git/containers/${repo}#${sha} --git-branch ${gitbranch} --nowait 2>/dev/null | tee 2>&1 "${tmpfile}"
+		tmpfile=$(mktemp) && brew container-build ${target} git+https://pkgs.devel.redhat.com/git/containers/${repo}#${sha} --git-branch ${gitbranch} ${scratchFlag} --nowait 2>/dev/null | tee 2>&1 "${tmpfile}"
 		taskID=$(cat "${tmpfile}" | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 "${tmpfile}"
 		ERRORS="$(grep "image build failed" "${tmpfile}")" && rm -f "${tmpfile}"
 		if [[ "$ERRORS" != "" ]]; then echo "Brew build has failed:
